/**
 * Returns textContent of passed domElement.
 *
 * @param domElement DOM element.
 *
 * @returns DOM element textContent.
 */
export declare const getNodeTextContent: (domElement: Node) => string;
/**
 * Returns element selector text based on it's tagName and attributes.
 *
 * @param element DOM element.
 *
 * @returns String representation of `element`.
 */
export declare const getElementSelectorDesc: (element: Element) => string;
/**
 * Returns path to a DOM element as a selector string.
 *
 * @param inputEl Input element.
 *
 * @returns String path to a DOM element.
 * @throws An error if `inputEl` in not instance of `Element`.
 */
export declare const getElementSelectorPath: (inputEl: Element) => string;
/**
 * Checks whether the element is instance of HTMLElement.
 *
 * @param element Element to check.
 *
 * @returns True if `element` is HTMLElement.
 */
export declare const isHtmlElement: (element: HTMLElement | Node | null) => element is HTMLElement;
/**
 * Takes `element` and returns its parent element.
 *
 * @param element Element.
 * @param errorMessage Optional error message to throw.
 *
 * @returns Parent of `element`.
 * @throws An error if element has no parent element.
 */
export declare const getParent: (element: HTMLElement, errorMessage?: string) => HTMLElement;
